@@ -7,7 +7,7 @@ use MeCab;
 
 print $MeCab::VERSION, "\n";
 
-my $sentence = "ϺϤܤϺ򸫤Ϥ";
+my $sentence = "太郎はこの本を二郎を見た女性に渡した。";
 
 my $c = new MeCab::Tagger(join " ", @ARGV);
 
